/*
   Unix SMB/CIFS implementation.
   smb2 wrapper client routines
   Copyright (C) Jeremy Allison 2013

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**************************************************************************
                           XEROX REVISION HISTORY

Date         Author                        Description
----------  -----------  -------------------------------------------------- 
07/09/2014  M Tompkins    CQGbl585847: SMB_COM_QUERY_INFORMATION_DISK call 
                            deprecated. PATCH from Jeremy Allison
**************************************************************************/


#ifndef __SMB2CLI_FNUM_H__
#define __SMB2CLI_FNUM_H__

struct smbXcli_conn;
struct smbXcli_session;
struct cli_state;
struct file_info;

NTSTATUS smb2cli_create_fnum(struct cli_state *cli,
			const char *fname,
			uint32_t create_flags,
			uint32_t desired_access,
			uint32_t file_attributes,
			uint32_t share_access,
			uint32_t create_disposition,
			uint32_t create_options,
			uint16_t *pfid,
			struct smb2_create_returns *cr);

NTSTATUS smb2cli_close_fnum(struct cli_state *cli, uint16_t fnum);
NTSTATUS smb2cli_mkdir(struct cli_state *cli, const char *dirname);
NTSTATUS smb2cli_rmdir(struct cli_state *cli, const char *dirname);
NTSTATUS smb2cli_unlink(struct cli_state *cli,const char *fname);
NTSTATUS smb2cli_list(struct cli_state *cli,
			const char *pathname,
			uint16_t attribute,
			NTSTATUS (*fn)(const char *,
				struct file_info *,
				const char *,
				void *),
			void *state);
NTSTATUS smb2cli_qpathinfo_basic(struct cli_state *cli,
			const char *name,
			SMB_STRUCT_STAT *sbuf,
			uint32_t *attributes);
NTSTATUS smb2cli_qpathinfo_alt_name(struct cli_state *cli,
			const char *name,
			fstring alt_name);
NTSTATUS smb2cli_qfileinfo_basic(struct cli_state *cli,
			uint16_t fnum,
			uint16_t *mode,
			off_t *size,
			struct timespec *create_time,
			struct timespec *access_time,
			struct timespec *write_time,
			struct timespec *change_time,
			SMB_INO_T *ino);
NTSTATUS smb2cli_getattrE(struct cli_state *cli,
			uint16_t fnum,
			uint16_t *attr,
			off_t *size,
			time_t *change_time,
			time_t *access_time,
			time_t *write_time);
NTSTATUS smb2cli_qpathinfo2(struct cli_state *cli,
			const char *fname,
			struct timespec *create_time,
			struct timespec *access_time,
			struct timespec *write_time,
			struct timespec *change_time,
			off_t *size,
			uint16_t *mode,
			SMB_INO_T *ino);
NTSTATUS smb2cli_qpathinfo_streams(struct cli_state *cli,
			const char *name,
			TALLOC_CTX *mem_ctx,
			unsigned int *pnum_streams,
			struct stream_struct **pstreams);
NTSTATUS smb2cli_setatr(struct cli_state *cli,
			const char *fname,
			uint16_t attr,
			time_t mtime);
NTSTATUS smb2cli_setattrE(struct cli_state *cli,
                        uint16_t fnum,
                        time_t change_time,
                        time_t access_time,
                        time_t write_time);
NTSTATUS smb2cli_dskattr(struct cli_state *cli,
#ifdef XEROX_MODIFICATION_SMB   // PATCH
			uint64_t *bsize,
			uint64_t *total,
			uint64_t *avail);
#else
			int *bsize,
			int *total,
			int *avail);
#endif // XEROX_MODIFICATION_SMB
NTSTATUS smb2cli_query_security_descriptor(struct cli_state *cli,
			uint16_t fnum,
			uint32_t sec_info,
			TALLOC_CTX *mem_ctx,
			struct security_descriptor **ppsd);
NTSTATUS smb2cli_set_security_descriptor(struct cli_state *cli,
			uint16_t fnum,
			uint32_t sec_info,
			const struct security_descriptor *sd);
NTSTATUS smb2cli_rename(struct cli_state *cli,
			const char *fname_src,
			const char *fname_dst);
struct tevent_req *smb2cli_readall_fnum_send(TALLOC_CTX *mem_ctx,
			struct tevent_context *ev,
			struct cli_state *cli,
			uint16_t fnum,
			off_t offset,
			size_t size);
NTSTATUS smb2cli_readall_fnum_recv(struct tevent_req *req,
			ssize_t *received,
			uint8_t **rcvbuf);
struct tevent_req *smb2cli_writeall_send(TALLOC_CTX *mem_ctx,
			struct tevent_context *ev,
			struct cli_state *cli,
			uint16_t fnum,
			uint16_t mode,
			const uint8_t *buf,
			off_t offset,
			size_t size);
NTSTATUS smb2cli_writeall_recv(struct tevent_req *req,
			size_t *pwritten);
#endif /* __SMB2CLI_FNUM_H__ */
